@@ -1,10 +1,10 @@
 #include <iostream>
 #include "plocate.h"
 
-int main(int argc, char *argv[])
+int main()
 {
 	vector<string> fs,prunefs;
-	read_plocate(fs,prunefs);
+	read_plocate(fs,prunefs, "/etc/cruft/ignore");
 
 	cout << '/' << endl;
 	for (unsigned int i=0;i<fs.size();i++) {
